@@ -23,6 +23,25 @@ class ItemNotFoundException(CloudbaseInitException):
     pass
 
 
+class ServiceException(Exception):
+
+    """Base exception for all the metadata services related errors."""
+
+    pass
+
+
+class CertificateVerifyFailed(ServiceException):
+
+    """The received certificate is not valid.
+
+    In order to avoid the current exception the validation of the SSL
+    certificate should be disabled for the metadata provider. In order
+    to do that the `https_allow_insecure` config option should be set.
+    """
+
+    pass
+
+
 class WindowsCloudbaseInitException(CloudbaseInitException):
 
     def __init__(self, msg="%r", error_code=None):
