@@ -12,33 +12,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
 from oslo_log import log as oslo_logging
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import exception
 from cloudbaseinit.utils import classloader
 
 
-opts = [
-    cfg.ListOpt(
-        'metadata_services',
-        default=[
-            'cloudbaseinit.metadata.services.httpservice.HttpService',
-            'cloudbaseinit.metadata.services.configdrive.ConfigDriveService',
-            'cloudbaseinit.metadata.services.ec2service.EC2Service',
-            'cloudbaseinit.metadata.services.maasservice.MaaSHttpService',
-            'cloudbaseinit.metadata.services.cloudstack.CloudStack',
-            'cloudbaseinit.metadata.services'
-            '.opennebulaservice.OpenNebulaService',
-        ],
-        help='List of enabled metadata service classes, '
-        'to be tested for availability in the provided order. '
-        'The first available service will be used to retrieve '
-        'metadata')
-]
-
-CONF = cfg.CONF
-CONF.register_opts(opts)
+CONF = cloudbaseinit_conf.CONF
 LOG = oslo_logging.getLogger(__name__)
 
 
