@@ -14,23 +14,14 @@
 
 import struct
 
-from oslo_config import cfg
 from oslo_log import log as oslo_logging
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit.osutils import factory as osutils_factory
 from cloudbaseinit.plugins.common import base
 from cloudbaseinit.utils import dhcp
 
-
-opts = [
-    cfg.BoolOpt('mtu_use_dhcp_config', default=True,
-                help='Configures the network interfaces MTU based on the '
-                     'values provided via DHCP'),
-]
-
-CONF = cfg.CONF
-CONF.register_opts(opts)
-
+CONF = cloudbaseinit_conf.CONF
 LOG = oslo_logging.getLogger(__name__)
 
 
