@@ -22,13 +22,13 @@ try:
     import unittest.mock as mock
 except ImportError:
     import mock
-from oslo_config import cfg
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import exception
 from cloudbaseinit.tests import testutils
 
 
-CONF = cfg.CONF
+CONF = cloudbaseinit_conf.CONF
 
 OPEN = mock.mock_open()
 
