@@ -20,14 +20,14 @@ try:
     import unittest.mock as mock
 except ImportError:
     import mock
-from oslo_config import cfg
 from six.moves import urllib
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit.metadata.services import base
 from cloudbaseinit.metadata.services import cloudstack
 from cloudbaseinit.tests import testutils
 
-CONF = cfg.CONF
+CONF = cloudbaseinit_conf.CONF
 
 
 class CloudStackTest(unittest.TestCase):
@@ -48,7 +48,6 @@ class CloudStackTest(unittest.TestCase):
         url = '127.0.0.1'
         mock_http_request.side_effect = [
             '200 OK. Successfully!',    # Request to Web Service
-            'service-offering',         # Response for get_data
             urllib.error.HTTPError(url=url, code=404, hdrs={}, fp=None,
                                    msg='Testing 404 Not Found.'),
             urllib.error.HTTPError(url=url, code=427, hdrs={}, fp=None,
@@ -65,8 +64,8 @@ class CloudStackTest(unittest.TestCase):
     @mock.patch('cloudbaseinit.metadata.services.cloudstack.CloudStack'
                 '._test_api')
     def test_load(self, mock_test_api, mock_os_util):
-        self._service.osutils.get_dhcp_hosts_in_use = mock.Mock()
-        self._service.osutils.get_dhcp_hosts_in_use.side_effect = [
+        self._service._osutils.get_dhcp_hosts_in_use = mock.Mock()
+        self._service._osutils.get_dhcp_hosts_in_use.side_effect = [
             [(mock.sentinel.mac_address, '10.10.0.1'),
              (mock.sentinel.mac_address, '10.10.0.2'),
              (mock.sentinel.mac_address, '10.10.0.3')]
@@ -83,25 +82,27 @@ class CloudStackTest(unittest.TestCase):
         self._service._test_api = mock_test_api
 
         self.assertTrue(self._service.load())
-        mock_test_api.assert_called_once_with(CONF.cloudstack_metadata_ip)
+        mock_test_api.assert_called_once_with(
+            CONF.cloudstack.metadata_base_url)
 
     @mock.patch('cloudbaseinit.osutils.factory.get_os_utils')
     @mock.patch('cloudbaseinit.metadata.services.cloudstack.CloudStack'
                 '._test_api')
     def test_load_fail(self, mock_test_api, mock_os_util):
-        self._service.osutils.get_dhcp_hosts_in_use.side_effect = [None]
+        self._service._osutils.get_dhcp_hosts_in_use.side_effect = [None]
         mock_test_api.side_effect = [False]
 
         self.assertFalse(self._service.load())  # No DHCP server was found.
-        mock_test_api.assert_called_once_with(CONF.cloudstack_metadata_ip)
+        mock_test_api.assert_called_once_with(
+            CONF.cloudstack.metadata_base_url)
 
     @mock.patch('cloudbaseinit.osutils.factory.get_os_utils')
     @mock.patch('cloudbaseinit.metadata.services.cloudstack.CloudStack'
                 '._test_api')
     def test_load_no_service(self, mock_test_api, mock_os_util):
-        self._service.osutils.get_dhcp_hosts_in_use = mock.Mock()
-        self._service.osutils.get_dhcp_hosts_in_use.side_effect = [
-            [(mock.sentinel.mac_address, CONF.cloudstack_metadata_ip)]
+        self._service._osutils.get_dhcp_hosts_in_use = mock.Mock()
+        self._service._osutils.get_dhcp_hosts_in_use.side_effect = [
+            [(mock.sentinel.mac_address, CONF.cloudstack.metadata_base_url)]
         ]
         mock_test_api.side_effect = [False, False]
 
@@ -109,29 +110,6 @@ class CloudStackTest(unittest.TestCase):
         self.assertFalse(self._service.load())
         self.assertEqual(2, mock_test_api.call_count)
 
-    @mock.patch('cloudbaseinit.metadata.services.cloudstack.CloudStack'
-                '._http_request')
-    def test_get_data(self, mock_http_request):
-        metadata = 'service-offering'
-        mock_http_request.side_effect = [
-            mock.sentinel.ok,
-            urllib.error.HTTPError(url=metadata, code=404, hdrs={}, fp=None,
-                                   msg='Testing 404 Not Found.'),
-            urllib.error.HTTPError(url=metadata, code=427, hdrs={}, fp=None,
-                                   msg='Testing 429 Too Many Requests.')
-        ]
-
-        for status in (200, 404, 427):
-            if status == 200:
-                response = self._service._get_data(metadata)
-                self.assertEqual(mock.sentinel.ok, response)
-            elif status == 404:
-                self.assertRaises(base.NotExistingMetadataException,
-                                  self._service._get_data, metadata)
-            else:
-                self.assertRaises(urllib.error.HTTPError,
-                                  self._service._get_data, metadata)
-
     @mock.patch('cloudbaseinit.metadata.services.cloudstack.CloudStack'
                 '._get_data')
     def test_get_cache_data(self, mock_get_data):
@@ -164,15 +142,15 @@ class CloudStackTest(unittest.TestCase):
 
     def test_get_instance_id(self):
         self._test_cache_response(method=self._service.get_instance_id,
-                                  metadata='instance-id')
+                                  metadata='latest/meta-data/instance-id')
 
     def test_get_host_name(self):
         self._test_cache_response(method=self._service.get_host_name,
-                                  metadata='local-hostname')
+                                  metadata='latest/meta-data/local-hostname')
 
     def test_get_user_data(self):
         self._test_cache_response(method=self._service.get_user_data,
-                                  metadata='../user-data', decode=False)
+                                  metadata='latest/user-data', decode=False)
 
     @mock.patch('cloudbaseinit.metadata.services.cloudstack.CloudStack'
                 '._get_cache_data')
@@ -192,24 +170,6 @@ class CloudStackTest(unittest.TestCase):
             response = self._service.get_public_keys()
             self.assertEqual([], response)
 
-    @mock.patch('six.moves.urllib.request')
-    def test__http_request(self, mock_urllib_request):
-        mock_urllib_request.Request.return_value = mock.sentinel.request
-        with testutils.LogSnatcher('cloudbaseinit.metadata.services.'
-                                   'cloudstack') as snatcher:
-            self._service._http_request(mock.sentinel.url)
-
-        expected_logging = [
-            'Getting metadata from:  %s' % mock.sentinel.url,
-        ]
-        mock_urllib_request.Request.assert_called_once_with(
-            mock.sentinel.url)
-        mock_urllib_request.urlopen.assert_called_once_with(
-            mock.sentinel.request)
-        mock_urlopen = mock_urllib_request.urlopen.return_value
-        mock_urlopen.read.assert_called_once_with()
-        self.assertEqual(expected_logging, snatcher.output)
-
     @mock.patch('six.moves.http_client.HTTPConnection')
     def test_get_password(self, mock_http_connection):
         headers = {"DomU_Request": "send_my_password"}
