@@ -22,8 +22,8 @@ try:
     import unittest.mock as mock
 except ImportError:
     import mock
-from oslo_config import cfg
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import exception
 from cloudbaseinit.plugins.common.userdataplugins import cloudconfig
 from cloudbaseinit.plugins.common.userdataplugins.cloudconfigplugins import (
@@ -31,7 +31,7 @@ from cloudbaseinit.plugins.common.userdataplugins.cloudconfigplugins import (
 )
 from cloudbaseinit.tests import testutils
 
-CONF = cfg.CONF
+CONF = cloudbaseinit_conf.CONF
 
 
 def _create_tempfile():
