@@ -18,12 +18,12 @@ try:
     import unittest.mock as mock
 except ImportError:
     import mock
-from oslo_config import cfg
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit import exception
 from cloudbaseinit.plugins.windows import ntpclient
 
-CONF = cfg.CONF
+CONF = cloudbaseinit_conf.CONF
 
 
 class NTPClientPluginTests(unittest.TestCase):
