@@ -18,13 +18,13 @@ try:
     import unittest.mock as mock
 except ImportError:
     import mock
-from oslo_config import cfg
 
+from cloudbaseinit import conf as cloudbaseinit_conf
 from cloudbaseinit.tests import testutils
 from cloudbaseinit.utils import network
 
 
-CONF = cfg.CONF
+CONF = cloudbaseinit_conf.CONF
 
 
 class NetworkUtilsTest(unittest.TestCase):
